@@ -18,6 +18,11 @@ class Synapse(ABC):
         """
         return self.__class__.__name__
 
+    def print(self, funcname, request):
+        self.logger.info(funcname)
+        self.logger.info(request)
+        print()
+
     @property
     def logger(self):
         return SyncariLogger.get_logger(f"{self.name}")
